#
# spec file for package OpenLP
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           OpenLP
Version:        2.0.5
Release:        4.2
Summary:        Open source Church presentation and lyrics projection application
License:        GPL-2.0
Group:          Productivity/Multimedia/Other
Url:            http://openlp.org
Source0:        http://downloads.sourceforge.net/openlp/openlp/%{version}/%{name}-%{version}.tar.gz
Source1:        OpenLP-rpmlintrc

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  libqt4-devel
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  update-desktop-files
Requires:       hicolor-icon-theme
Requires:       libphonon4
Requires:       python-Mako
Requires:       python-SQLAlchemy
Requires:       python-beautifulsoup
Requires:       python-chardet
Requires:       python-lxml
Requires:       python-pyenchant
Requires:       python-qt4
Requires:       python-sqlalchemy-migrate
Requires:       python-xdg
Recommends:     libreoffice-pyuno
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
OpenLP is a church presentation software, for lyrics projection software,
used to display slides of Songs, Bible verses, videos, images, and
presentations via LibreOffice using a computer and projector.

%prep
%setup -q
# Needed to prevent /usr/lib/python2.7/site-packages/resources from being built
rm resources/__init__.py

%build
python setup.py build

# Compile the translation files and copy them to the correct directory
# Presumes you are in the base directory of OpenLP

%install
python setup.py install --skip-build -O1 --prefix=%{_prefix} --root=%{buildroot}

install -m644 -p -D resources/images/openlp-logo-16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo-32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo-48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/openlp.png
install -m644 -p -D resources/images/openlp-logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/openlp.svg

%suse_update_desktop_file -i -r openlp AudioVideo Video Player

mv %{buildroot}%{_bindir}/openlp.pyw %{buildroot}%{_bindir}/openlp

mkdir -p %{buildroot}%{_datadir}/openlp/i18n/
for TSFILE in resources/i18n/*.ts; do
    lrelease $TSFILE -qm %{buildroot}%{_datadir}/openlp/i18n/`basename $TSFILE .ts`.qm;
done

mkdir -p %{buildroot}%{_datadir}/mime/packages
cp -p resources/openlp.xml %{buildroot}%{_datadir}/mime/packages

# Deduplicate .pyc and .pyo files
%fdupes %{buildroot}%{python_sitelib}

%post
touch --no-create %{_datadir}/icons/hicolor ||:
gtk-update-icon-cache -q %{_datadir}/icons/hicolor 2> /dev/null ||:
update-mime-database %{_datadir}/mime > /dev/null 2>&1 ||:
update-desktop-database > /dev/null 2>&1 ||:

%postun
touch --no-create %{_datadir}/icons/hicolor ||:
gtk-update-icon-cache -q %{_datadir}/icons/hicolor 2> /dev/null ||:
update-mime-database %{_datadir}/mime > /dev/null 2>&1 ||:
update-desktop-database > /dev/null 2>&1 ||:

%files
%defattr(-,root,root)
%doc copyright.txt LICENSE
%{_bindir}/openlp
%{_datadir}/mime/packages/openlp.xml
%{_datadir}/applications/openlp.desktop
%{_datadir}/icons/hicolor
%{_datadir}/openlp
%{python_sitelib}/openlp/
%{python_sitelib}/%{name}-%{version}*.egg-info

%changelog
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Tue Jul  1 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song (lp#1310523)
  * Handle songs where two optional breaks follow each other (lp#1296104)
  * Improve Database update error handling (lp#1136278)
* Mon Jun 30 2014 joseph@mulloy.me
- Updated to 2.0.5 (bnc#884901)
  * Upstream bugfix/stabilization release
  * Final release in the 2.0 branch
  * Change to BibleGateway URL to use legacy web interface
  * Issues with Themes when comparing theme files (lp#719514)
  * Improved error messages with Easy Worship Song Imports (lp#1326664)
  * Allow more than 26 equal verses within a Song. (lp#1310523)
  * Handle songs where two optional breaks follow each other. (lp#1296104)
  * Improve Database update error handling. (lp#1136278)
* Sat Feb 15 2014 joseph@mulloy.me
- Updated to 2.0.4 (bnc#864175)
  * Upstream bugfix/stabilization release
- Bugs fixed in this release
  * lp#1154467: Web download bible db's getting locked
  * lp#1173749: Songs with mismatching formatting tags still throw
    an exception
  * lp#1252477: Changing theme on bible settings tab causes an
    error when saving service
  * lp#1012110: pptviewlib does not accept unicode filename
  * lp#1199639: Formatting tags opened and closed in different
    verses throw an exception
  * lp#1206886: HTTP Server gets deleted
  * lp#1222534: KeyError when "Allow presentation application to be
    overridden" and Spanish language is selected
  * lp#1223841: Transition does not work if texts are the same
  * lp#1225763: Replacing background with video unblank screen even
    if "Blanked to Theme"
  * lp#1251437: BibleGateway importer crashes on non unicode urls
  * lp#1258634: TypeError when saving service from previous versions
    with notes
  * lp#1259606: Clicking Verse Button doesn't alter live slide
  * lp#1266271: Output display returns after pressing esc when
    looping slides
  * lp#1157938: "Alt + Tab" = some pixelated icons and missing icons
  * lp#1211049: Can no long download bible verses
  * lp#1216234: Layout style has not effect when using a second bible
  * lp#1240942: Troubleshooting guide is outdated
  * lp#1265368: [regression] Traceback in web remote
  * lp#1163874: Add Slovak bible to First Run Wizard
* Wed Dec 18 2013 hrvoje.senjan@gmail.com
- Phonon package exists only via provides, so don't make OpenLP
  package require it - provide will go away soon
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Sep 20 2013 jdmulloy@gmail.com
- Update to 2.0.3 (bnc#841394)
  * Fixes regression introduced in 2.0.2 that prevents saving
    service files with notes in them (lp#1216785)
* Fri Aug 30 2013 jdmulloy@gmail.com
- Update to 2.0.2 (bnc#837706):
  * Upstream bugfix/stabilization release
  * Improvements/Bugfixes for UI, Song Importers and more
* Mon Jan  7 2013 alexandre@exatati.com.br
- Update to 2.0.1:
  * Song export and import now works correctly
  * Transparent themes are once again transparent
  * PowerPoint/Impress files with unicode characters in the filename
    can be imported
  * OpenLP is now more usable with the XFCE desktop on Linux
* Fri Dec  7 2012 jdmulloy@gmail.com
- Updated to OpenLP 2.0
  * Stable release of OpenLP 2.0
* Tue Sep 25 2012 jdmulloy@gmail.com
- Updated from version 1.9.11 (2.0 RC1) to version 1.9.12 (2.0 RC2)
  * Includes various bugfixes
- Added rpmlintrc to suppress spurious RPMLINT warnings
- Deleted obsolete patch file uno-path.patch
* Wed Aug  8 2012 jdmulloy@gmail.com
- Bumped version from 1.9.10 (2.0 RC1) to 1.9.11 (2.0 RC2)
- Includes various bugfixes
* Sun Jul  8 2012 jdmulloy@gmail.com
- Bumped version from 1.9.9 to 1.9.10
- Removed uno-path.patch as libreoffice-pyuno has been fixed
- Fixed missing translations bug (lp#1007148)
- Fixed error in %%suse_update_desktop_file argument order
* Sat Mar 24 2012 jdmulloy@gmail.com
- Bumped version from 1.9.8 to 1.9.9
- Removed openlp-1.9.8-impress-segfault-backport.patch because the
  upstream release incorporates the fix
* Mon Mar 19 2012 jdmulloy@gmail.com
- Added python-xdg as a dependency so that data files are always
  stored in ~/.local/share/openlp
* Sun Mar 11 2012 jdmulloy@gmail.com
- Changed download_files service mode to localonly to comply with
  Factory rules
* Tue Mar  6 2012 jdmulloy@gmail.com
- Added openlp-1.9.8-impress-segfault-backport.patch which
  backports fix from upstream to bnc#748241.
  Patch can be removed in the next release from upstream
* Thu Feb 23 2012 saschpe@suse.de
- Actually add a tarball ;-)
- Spec file cleanup:
  * Adjust dependency names to what we currently have in d:l:p / Factory
  * Simplified macro usage
* Wed Feb 22 2012 jdmulloy@gmail.com
- Removed download service and manually uploaded tarball for
  submission to Factory
* Tue Feb 21 2012 jdmulloy@gmail.com
- Cleaned up spec file to make it more readable
- Added conditional to prevent application of uno-path patch on
  openSUSE > 12.1
  * Bug in libreoffice-pyuno is fixed in Factory (12.2)
* Sun Dec 25 2011 jdmulloy@gmail.com
- Bumped OpenLP version from 1.9.7 to 1.9.8
- Cleaned up spec file
* Mon Dec  5 2011 jdmulloy@gmail.com
- Added uno-path.patch to make 'import uno' work
  * This patch, patches the two files that call 'import uno'.
  It appends the appropriate path to sys.path so that python can
  find the uno module.
- Added %%fdupes to %%install section to resolve RPMLINT warnings
* Thu Dec  1 2011 jdmulloy@gmail.com
- Changed Release: tag to use %%mkrel
* Wed Nov 30 2011 jdmulloy@gmail.com
- Removed unessecary dependencies
  * Removed libreoffice-graphicfilter and libreoffice-headless which
  are part of libreoffice in OpenSuse
  * Removed python-openoffice as it is not actually used by OpenLP
- Corrected dependency names
  * Corrected capitalization for python-beautifulsoup
  * Changed python-migrate to python-sqlalchemy-migrate
- Added libreoffice-pyuno to dependency list
* Mon Nov 28 2011 alexandre@exatati.com.br
- License on SPDX format;
- Fix Group in spec file.
* Thu Nov 24 2011 alexandre@exatati.com.br
- Reworked spec file;
- Work start from home:jdmulloy:openlp.
